@@ -213,6 +213,8 @@ def print_version_msg():
               'increase the verbosity. I.e.: -vvvv')
 @click.option('--interpret-escapes', '-e', is_flag=True,
               help='Enable interpretation of backslash escapes')
+@click.option('--interpret-emojis', '-j', is_flag=True,
+              help='Enable interpretation of :emoji: definitions')
 @click.option('--debug', '-D', is_flag=True, help='Debug mode')
 @click.option('--version', '-V', is_flag=True,
               help='Display the apprise version and exit.')
@@ -220,7 +222,8 @@ def print_version_msg():
                 metavar='SERVER_URL [SERVER_URL2 [SERVER_URL3]]',)
 def main(body, title, config, attach, urls, notification_type, theme, tag,
          input_format, dry_run, recursion_depth, verbose, disable_async,
-         details, interpret_escapes, plugin_path, debug, version):
+         details, interpret_escapes, interpret_emojis, plugin_path, debug,
+         version):
     """
     Send a notification to all of the specified servers identified by their
     URLs the content provided within the title, body and notification-type.
@@ -308,6 +311,9 @@ def main(body, title, config, attach, urls, notification_type, theme, tag,
         # Interpret Escapes
         interpret_escapes=interpret_escapes,
 
+        # Interpret Emojis
+        interpret_emojis=None if not interpret_emojis else True,
+
         # Set the theme
         theme=theme,
 
