@@ -27,12 +27,8 @@
 # POSSIBILITY OF SUCH DAMAGE.
 
 import os
-import re
 import copy
 
-from os.path import dirname
-from os.path import abspath
-
 # Used for testing
 from .NotifyBase import NotifyBase
 
@@ -40,13 +36,17 @@ from ..common import NotifyImageSize
 from ..common import NOTIFY_IMAGE_SIZES
 from ..common import NotifyType
 from ..common import NOTIFY_TYPES
-from .. import common
 from ..utils import parse_list
 from ..utils import cwe312_url
 from ..utils import GET_SCHEMA_RE
 from ..logger import logger
 from ..AppriseLocale import gettext_lazy as _
 from ..AppriseLocale import LazyTranslation
+from ..NotificationManager import NotificationManager
+
+
+# Grant access to our Notification Manager Singleton
+N_MGR = NotificationManager()
 
 __all__ = [
     # Reference
@@ -58,101 +58,6 @@ __all__ = [
 ]
 
 
-# Load our Lookup Matrix
-def __load_matrix(path=abspath(dirname(__file__)), name='apprise.plugins'):
-    """
-    Dynamically load our schema map; this allows us to gracefully
-    skip over modules we simply don't have the dependencies for.
-
-    """
-    # Used for the detection of additional Notify Services objects
-    # The .py extension is optional as we support loading directories too
-    module_re = re.compile(r'^(?P<name>Notify[a-z0-9]+)(\.py)?$', re.I)
-
-    for f in os.listdir(path):
-        match = module_re.match(f)
-        if not match:
-            # keep going
-            continue
-
-        # Store our notification/plugin name:
-        plugin_name = match.group('name')
-        try:
-            module = __import__(
-                '{}.{}'.format(name, plugin_name),
-                globals(), locals(),
-                fromlist=[plugin_name])
-
-        except ImportError:
-            # No problem, we can't use this object
-            continue
-
-        if not hasattr(module, plugin_name):
-            # Not a library we can load as it doesn't follow the simple rule
-            # that the class must bear the same name as the notification
-            # file itself.
-            continue
-
-        # Get our plugin
-        plugin = getattr(module, plugin_name)
-        if not hasattr(plugin, 'app_id'):
-            # Filter out non-notification modules
-            continue
-
-        elif plugin_name in common.NOTIFY_MODULE_MAP:
-            # we're already handling this object
-            continue
-
-        # Add our plugin name to our module map
-        common.NOTIFY_MODULE_MAP[plugin_name] = {
-            'plugin': plugin,
-            'module': module,
-        }
-
-        # Add our module name to our __all__
-        __all__.append(plugin_name)
-
-        fn = getattr(plugin, 'schemas', None)
-        schemas = set([]) if not callable(fn) else fn(plugin)
-
-        # map our schema to our plugin
-        for schema in schemas:
-            if schema in common.NOTIFY_SCHEMA_MAP:
-                logger.error(
-                    "Notification schema ({}) mismatch detected - {} to {}"
-                    .format(schema, common.NOTIFY_SCHEMA_MAP[schema], plugin))
-                continue
-
-            # Assign plugin
-            common.NOTIFY_SCHEMA_MAP[schema] = plugin
-
-    return common.NOTIFY_SCHEMA_MAP
-
-
-# Reset our Lookup Matrix
-def __reset_matrix():
-    """
-    Restores the Lookup matrix to it's base setting. This is only used through
-    testing and should not be directly called.
-    """
-
-    # Reset our schema map
-    common.NOTIFY_SCHEMA_MAP.clear()
-
-    # Iterate over our module map so we can clear out our __all__ and globals
-    for plugin_name in common.NOTIFY_MODULE_MAP.keys():
-
-        # Remove element from plugins
-        __all__.remove(plugin_name)
-
-    # Clear out our module map
-    common.NOTIFY_MODULE_MAP.clear()
-
-
-# Dynamically build our schema base
-__load_matrix()
-
-
 def _sanitize_token(tokens, default_delimiter):
     """
     This is called by the details() function and santizes the output by
@@ -176,6 +81,10 @@ def _sanitize_token(tokens, default_delimiter):
             # Do not touch this field
             continue
 
+        elif 'name' not in tokens[key]:
+            # Default to key
+            tokens[key]['name'] = key
+
         if 'map_to' not in tokens[key]:
             # Default type to key
             tokens[key]['map_to'] = key
@@ -538,16 +447,16 @@ def url_to_dict(url, secure_logging=True):
 
     # Ensure our schema is always in lower case
     schema = schema.group('schema').lower()
-    if schema not in common.NOTIFY_SCHEMA_MAP:
+    if schema not in N_MGR:
         # Give the user the benefit of the doubt that the user may be using
         # one of the URLs provided to them by their notification service.
         # Before we fail for good, just scan all the plugins that support the
         # native_url() parse function
-        results = \
-            next((r['plugin'].parse_native_url(_url)
-                  for r in common.NOTIFY_MODULE_MAP.values()
-                  if r['plugin'].parse_native_url(_url) is not None),
-                 None)
+        results = None
+        for plugin in N_MGR.plugins():
+            results = plugin.parse_native_url(_url)
+            if results:
+                break
 
         if not results:
             logger.error('Unparseable URL {}'.format(loggable_url))
@@ -560,14 +469,14 @@ def url_to_dict(url, secure_logging=True):
     else:
         # Parse our url details of the server object as dictionary
         # containing all of the information parsed from our URL
-        results = common.NOTIFY_SCHEMA_MAP[schema].parse_url(_url)
+        results = N_MGR[schema].parse_url(_url)
         if not results:
             logger.error('Unparseable {} URL {}'.format(
-                common.NOTIFY_SCHEMA_MAP[schema].service_name, loggable_url))
+                N_MGR[schema].service_name, loggable_url))
             return None
 
         logger.trace('{} URL {} unpacked as:{}{}'.format(
-            common.NOTIFY_SCHEMA_MAP[schema].service_name, url,
+            N_MGR[schema].service_name, url,
             os.linesep, os.linesep.join(
                 ['{}="{}"'.format(k, v) for k, v in results.items()])))
 
